pub struct RoomJoinRulesEvent<E: Event>(/* private fields */);Expand description
A helper type for an Event of type m.room.join_rules.
This is a type that deserializes each field lazily, when requested.
Implementations